body {
	padding-bottom: 40px;
	font-family: 'Open Sans' sans-serif;
	background-color: #f6f6f6;
}

h1 {
	font-family: 'Open Sans' sans-serif;
	font-size: 34px;
	letter-spacing: -1.5px;
	font-weight: bold;
	color: #2e2e2e;
	line-height: 1.2;
}

ul.no-style {
	list-style-type: none;
}

.menu.col-md-12 {
	background-color: #222233;
	border-bottom: 1px solid #4D4C4C;
}

.logo-tsuru {
	max-width: 100px;
	padding: 13px 0;
	display: inline-block;
}

.logo-tsuru img {
	max-width: 100px;
	height: auto;
}

.drop {
	display: inline-block;
	float: right;
	position: relative;
	right: 35px;
	top: 15px;
}

.userbar {
	background-color: #222233;
	opacity: 0.9;
}

.sidebar.navbar {
	margin-bottom: 0;
	min-height: 0;
	border: 0;
}

.sidebar .nav > li {
	padding: 4px 0;
}

.sidebar .nav > li > a {
	color: #fff;
	font-size: 13px;
	padding: 6px 20px;
}

.sidebar .nav > li > a:hover,
.sidebar .nav > li > a:focus,
.sidebar .nav > li.active > a {
	background-color: rgba(255,255,255,0.2);
}

.dropdown-menu {
	position: absolute;
	right: 10px;
	left: inherit;
}

.dropdown-toggle:focus {
	outline: 0 none;
}

select {
	width: 125px;
	margin-bottom: 20px;
}

.admin-menu {
	color: #fff;
	border-top: 3px solid #fff;
}

.report-issue {
	color: #fff;
	position: absolute;
	bottom: 55px;
	padding-left: 40px;
}

.report-issue a {
	color: #fff;
	text-decoration: none;
}

.col-md-10.app-teams {
	padding-bottom: 5px;
}

.table th, .table td {
	vertical-align: middle;
}

.pager {
	padding-top: 20px;
	padding-left: 40px;
}

.pager .page a {
	border: 3px solid #bbbbbb;
	margin-left: 1px;
	margin-right: 1px;
	padding-left: 4px;
	padding-right: 4px;
	text-decoration: none;
	color: #000000;
}

.pager .current {
	  border: 3px solid #444444;
	  margin-left: 2px;
	  margin-right: 2px;
	  padding-left: 2px;
}

.text-right-important {
	text-align: right !important;
}

.ssh-key {
	word-break: break-all;
	color: #555;
}

.col-md-12 .col-md-12 {
	padding: 0;
}

.breadcrumb-bar {
	background-color: #fff;
	box-shadow: 0 1px 2px 0 rgba(0, 0, 0, 0.3);
	padding-left: 33px;
}

.bar {
	font-size: 14px;
	letter-spacing: -0.2px;
	color: #666;
	padding: 10px 0;
}

.bar a {
	color: #0769de;
}

.bar a:hover {
	color: #2445b1;
}

.bar span.arrow {
	padding: 0 16px;
}

.bar button {
	width: 100px;
	height: 40px;
	border-radius: 4px;
	background-color: #0769de;
	box-shadow: inset 0 -2px 0 0 rgba(0, 0, 0, 0.3);
	line-height: 0;
	position: absolute;
	right: 24px;
	top: 16px;
	color: #fff;
	border: 0;
}

.bar button:hover {
	background-color: #2445b1;
}

.button {
	width: 100px;
	height: 40px;
	border-radius: 4px;
	background-color: #0769de;
	box-shadow: inset 0 -2px 0 0 rgba(0, 0, 0, 0.3);
	line-height: 0;
	color: #fff;
	border: 0;
}

.button:hover {
	background-color: #2445b1;
}

.button[disabled] {
	cursor: not-allowed;
	background-color: #dddddd;
}
