.header-wrapper {
  display: flex;
  padding: 20px 0 10px;
  align-items: center;
}

.header-wrapper h1 {
  margin: 0;
}

.header-wrapper a {
  margin: 5px 0 0 20px;
  font-size: 24px;
  flex-basis: auto;
  align-self: center;
}
