<div class="pager">
  {% if previous %}
  <span class="page">
    <a href="?page={{ previous }}">&lt; Prev</a>
  </span>
  {% endif %}

  {% if next %}
  <span class="page"><a href="?page={{ next }}">Next &gt;</a></span>
  {% endif %}
</div>
